# 7i96
7i96 Configuration Tool

Scope

Read in the ini configuration file for changes.

Create a complete configuration from scratch.

Depends on python3-pyqt5

sudo apt-get install python3-pqt5

Open the sample ini file then make changes as needed then build

You can create a configuration then run it with the Axis GUI and use
Machine > Calibration to tune each axis. Save the values to the ini file and
next time you run the 7i96 Configuration Tool it will read the values from the
ini file.
